abacusai.video_gen_settings — AbacusAI documentation

# abacusai.video_gen_settings

## Classes

`VideoGenSettings` | Video generation settings

## Module Contents

class abacusai.video_gen_settings.VideoGenSettings(client, model=None, settings=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Video generation settings

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - model (dict) – The model settings.

    - settings (dict) – The settings for each model.

  model
  settings
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict